aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/voip.h
diff options
context:
space:
mode:
authorBlack Hat <bhat@encom.eu.org>2019-09-26 22:22:36 -0700
committerBlack Hat <bhat@encom.eu.org>2019-09-26 22:22:36 -0700
commit363cf452bcdbaf6ff1cf94a83ca66cbb31122346 (patch)
treec64c8fda885e4e1785130e8ee3e7c47fd18cbf67 /lib/csapi/voip.h
parent412e2cf19449e73aa7da729e9c5de6502687aade (diff)
parent944653463fe4134c82d85e2d01e2bc0fa43fd727 (diff)
downloadlibquotient-363cf452bcdbaf6ff1cf94a83ca66cbb31122346.tar.gz
libquotient-363cf452bcdbaf6ff1cf94a83ca66cbb31122346.zip
Merge branch 'master' of https://github.com/quotient-im/libQuotient into
bhat-libqtolm-update
Diffstat (limited to 'lib/csapi/voip.h')
-rw-r--r--lib/csapi/voip.h73
1 files changed, 38 insertions, 35 deletions
diff --git a/lib/csapi/voip.h b/lib/csapi/voip.h
index bb858499..38abfa27 100644
--- a/lib/csapi/voip.h
+++ b/lib/csapi/voip.h
@@ -8,39 +8,42 @@
#include <QtCore/QJsonObject>
-namespace QMatrixClient
+namespace Quotient
{
- // Operations
-
- /// Obtain TURN server credentials.
- ///
- /// This API provides credentials for the client to use when initiating
- /// calls.
- class GetTurnServerJob : public BaseJob
- {
- public:
- explicit GetTurnServerJob();
-
- /*! Construct a URL without creating a full-fledged job object
- *
- * This function can be used when a URL for
- * GetTurnServerJob is necessary but the job
- * itself isn't.
- */
- static QUrl makeRequestUrl(QUrl baseUrl);
-
- ~GetTurnServerJob() override;
-
- // Result properties
-
- /// The TURN server credentials.
- const QJsonObject& data() const;
-
- protected:
- Status parseJson(const QJsonDocument& data) override;
-
- private:
- class Private;
- QScopedPointer<Private> d;
- };
-} // namespace QMatrixClient
+
+// Operations
+
+/// Obtain TURN server credentials.
+/*!
+ * This API provides credentials for the client to use when initiating
+ * calls.
+ */
+class GetTurnServerJob : public BaseJob
+{
+public:
+ explicit GetTurnServerJob();
+
+ /*! Construct a URL without creating a full-fledged job object
+ *
+ * This function can be used when a URL for
+ * GetTurnServerJob is necessary but the job
+ * itself isn't.
+ */
+ static QUrl makeRequestUrl(QUrl baseUrl);
+
+ ~GetTurnServerJob() override;
+
+ // Result properties
+
+ /// The TURN server credentials.
+ const QJsonObject& data() const;
+
+protected:
+ Status parseJson(const QJsonDocument& data) override;
+
+private:
+ class Private;
+ QScopedPointer<Private> d;
+};
+
+} // namespace Quotient